import unittest
from my_string_calculator import StringCalculator #Momo

class TestStudent3CasesOnMe(unittest.TestCase):
    def setUp(self):
        self.calc = StringCalculator()

    def test_empty_string(self):
        self.assertEqual(self.calc.add(""), 0)

    def test_single_number(self):
        self.assertEqual(self.calc.add("5"), 5)

    def test_multiple_numbers(self):
        self.assertEqual(self.calc.add("5,5"), 10)

    def test_unknown_amount_of_numbers(self):
        self.assertEqual(self.calc.add("1,2,3"), 6)
        self.assertEqual(self.calc.add("10,20,30,40"), 100)
        self.assertEqual(self.calc.add("1,2,3,4,5,6"), 21)

    def test_numbers_separated_by_newline(self):
        self.assertEqual(self.calc.add("1\n2"), 3)
        self.assertEqual(self.calc.add("1\n2\n3"), 6)
        self.assertEqual(self.calc.add("10,20\n30"), 60)

    def test_negative_number_exception(self):
        with self.assertRaises(ValueError) as e:
            self.calc.add("-1,2")
        self.assertEqual(str(e.exception), "Negatives not allowed: -1")

    def test_multiple_negative_numbers_exception(self):
        with self.assertRaises(ValueError) as e:
            self.calc.add("-1,-2,3")
        self.assertEqual(str(e.exception), "Negatives not allowed: -1, -2")

    def test_add_numbers_with_custom_delimiter(self):
        self.assertEqual(self.calc.add("//;\n1;2;3"), 6)

    def test_ignore_numbers_over_1000(self):
        self.assertEqual(self.calc.add("1,1001,2,3"), 6)

    def test_custom_delimiter_with_long_pattern(self):
        self.assertEqual(self.calc.add("//[***]\n1***2***3"), 6)
        self.assertEqual(self.calc.add("//[+++]\n1+++2+++3"), 6)
        self.assertEqual(self.calc.add("//[aa]\n1aa2aa3"), 6)

if __name__ == "__main__":
    unittest.main()
