import unittest
from my_string_calculator import StringCalculator  

class TestStudent5OnMyCode(unittest.TestCase):
    def setUp(self):
        self.calc = StringCalculator()

    def test_add_empty_string(self):
        self.assertEqual(self.calc.add(""), 0)

    def test_add_single_number(self):
        self.assertEqual(self.calc.add("1"), 1)

    def test_add_two_numbers(self):
        self.assertEqual(self.calc.add("1,2"), 3)

    def test_add_multiple_numbers(self):
        self.assertEqual(self.calc.add("1,2,3"), 6)
        self.assertEqual(self.calc.add("1,2,3,4,5"), 15)

    def test_add_ignores_empty_entries(self):
        self.assertEqual(self.calc.add("1,,2"), 3)
        self.assertEqual(self.calc.add("1, ,2"), 3)
        self.assertEqual(self.calc.add(",,1,,2,,,"), 3)

    def test_add_with_newlines_between_numbers(self):
        self.assertEqual(self.calc.add("1\n2,3"), 6)
        self.assertEqual(self.calc.add("1,2\n3"), 6)
        self.assertEqual(self.calc.add("1\n2\n3"), 6)

    def test_add_raises_exception_on_negative_number(self):
        with self.assertRaises(ValueError) as context:
            self.calc.add("1,-2")
        self.assertIn("Negatives not allowed", str(context.exception))

    def test_add_raises_exception_on_multiple_negatives(self):
        with self.assertRaises(ValueError) as context:
            self.calc.add("-1,-2,3")
        self.assertIn("Negatives not allowed", str(context.exception))

    def test_add_with_custom_delimiter(self):
        self.assertEqual(self.calc.add("//;\n1;2"), 3)
        self.assertEqual(self.calc.add("//|\n4|5|6"), 15)
        self.assertEqual(self.calc.add("//_\n7_8_9"), 24)

    def test_add_ignores_numbers_greater_than_1000(self):
        self.assertEqual(self.calc.add("2,1001"), 2)
        self.assertEqual(self.calc.add("1000,1"), 1001)
        self.assertEqual(self.calc.add("1234,1001,3"), 3)

    def test_add_with_multi_char_delimiter(self):
        self.assertEqual(self.calc.add("//[***]\n1***2***3"), 6)
        self.assertEqual(self.calc.add("//[abc]\n4abc5abc6"), 15)
        self.assertEqual(self.calc.add("//[+]\n1+2+3"), 6)

if __name__ == "__main__":
    unittest.main()
